#!/usr/bin/python
#
# Graphical Hardware Management interface for Kudzu
# Copyright (c) 2001 Red Hat, Inc. All rights reserved.
#
# This software may be freely redistributed under the terms of the GNU
# public license.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# Author: Jonathan Blandford <jrb@redhat.com>


import os
import signal
import gettext

if __name__ == "__main__":
    signal.signal (signal.SIGINT, signal.SIG_DFL)

_=gettext.gettext

gettext.bindtextdomain("hwbrowser", "/usr/share/locale")
gettext.textdomain("hwbrowser")

(read, write) = os.pipe ()
pid = os.fork ()
if pid == 0:
    os.close (write)
    import gtk
    import GDK
    import gnome.ui
    def input_callback (*args):
        os._exit (0)
    gtk.input_add (read, GDK.INPUT_READ, input_callback)
    dialog = gnome.ui.GnomeMessageBox (_("Searching for hardware...\n\nNOTE: This may take a while, and your system may\nbecome unresponsive during this operation."), "info", "Button_Ok")
    dialog.run ()
    gtk.mainloop ()

import gnome.ui
import gtk
from gtk import TRUE, FALSE
import libglade
import kudzu
import string
import parted
import UserDict
import DeviceGeneric
import DeviceDisk
import gettext

class DeviceList (UserDict.UserDict):
    type_mapping = {
        kudzu.CLASS_AUDIO : _("Sound cards"),
        kudzu.CLASS_CAPTURE : _("Capture devices"),
        kudzu.CLASS_CDROM : _("CD-ROM Drives"),
        kudzu.CLASS_FLOPPY : _("Floppy Disks"),
        kudzu.CLASS_HD : _("Hard Drives"),
        kudzu.CLASS_KEYBOARD : _("Keyboards"),
        kudzu.CLASS_MODEM : _("Modems"),
        kudzu.CLASS_MONITOR : _("Monitors"),
        kudzu.CLASS_MOUSE : _("Pointing devices"),
        kudzu.CLASS_NETWORK : _("Network devices"),
        kudzu.CLASS_OTHER : _("System devices"),
        kudzu.CLASS_PRINTER : _("Printers"),
        kudzu.CLASS_RAID : _("RAID devices"),
        kudzu.CLASS_SCANNER : _("Scanners"),
        kudzu.CLASS_SCSI : _("SCSI devices"),
        kudzu.CLASS_SOCKET : _("PCMCIA/PC-Card devices"),
        kudzu.CLASS_TAPE : _("Tape Drives"),
        kudzu.CLASS_UNSPEC : _("Unknown devices"),
        kudzu.CLASS_USB : _("USB devices"),
        kudzu.CLASS_VIDEO : _("Video cards"),
        }

    def __init__ (self):
        self.data = {}
        self.hardware_read ()

    def get_category_string (self, key):
        return self.type_mapping[key]

    def hardware_read (self):
        for kudzu_device in kudzu.probe(kudzu.BUS_UNSPEC, kudzu.CLASS_UNSPEC, kudzu.PROBE_SAFE):
            device = DeviceType (kudzu_device)
            try:
                self[kudzu_device.deviceclass].append (device)
            except KeyError:
                self[kudzu_device.deviceclass] = [device]

    def hydrate_key (self, key):
        notebook = xml.get_widget ('category_notebook')
        if key == kudzu.CLASS_HD:
            notebook.set_page (1)
#        elif key == kudzu.CLASS_VIDEO:
#            notebook.set_page (2)
        else:
            notebook.set_page (0)
            DeviceGeneric.hydrate (self[key])
        
class DeviceType:
    def __init__ (self, kudzu_device):
        self.kudzu_device = kudzu_device

    def get_name (self):
        if string.find (self.kudzu_device.desc, "|") != -1:
            dummy, desc = string.split (self.kudzu_device.desc, "|")
        else:
            desc = self.kudzu_device.desc
        return desc


try:
    xml = libglade.GladeXML("/usr/share/hwbrowser/hwconf.glade", domain="hwbrowser")
    hardware = DeviceList ()
except:
    os.write (write, "die")
    dialog = gnome.ui.GnomeMessageBox (_("An error occurred while searching for hardware."), "error", "Button_Close")
    dialog.run ()
    os._exit (0)

if pid != 0:
    os.write (write, "die")
    os.close (write)

def reread_device_type_clist ():
    clist = xml.get_widget ('device_type_clist')
    clist.freeze ()
    clist.clear ()
    for key in hardware.keys ():
        row = clist.append ([hardware.get_category_string (key)])
        clist.set_row_data (row, key)
    clist.columns_autosize ()
    clist.sort ()
    clist.select_row (0, 0)
    clist.thaw ()

def setup_disk_view ():
    pass

def on_device_type_clist_select_row (clist, row, column, event):
    key = clist.get_row_data (row)
    if key == None:
        return
    hardware.hydrate_key (key)

def setup_ui ():
    DeviceGeneric.initialize (xml, hardware)
    DeviceDisk.initialize (xml, hardware)

def on_delete_event (*args):
    gtk.mainquit ()

if __name__ == "__main__":
    signal.signal (signal.SIGINT, signal.SIG_DFL)
    setup_ui ()
    xml.signal_autoconnect ({
        "on_device_type_clist_select_row" : on_device_type_clist_select_row,
        "on_delete_event" : on_delete_event
        })
    
    reread_device_type_clist ()
    gtk.mainloop ()
